### Intro to R script ###

# This line won't run because it's a comment
x

# x doesn't mean anything yet, let's make it mean something
x<-1
    
    # x now appear in the 'Global Environment' i.e. R knows what it means
x+2

# There are many classes of object: numeric, character, integer, logical
# Find the class of x with class()
class(x)

# Data can some in many structures: lists, vectors, dataframes, etc
# x is just a numeric
str(x)

# we can make a list called y
y <- c(1,2,3,4,5) # the c means we're making a list

# we can also use seq() to make lists
z<-seq(1,10, by=2)

# let's do some simple manipulations with these lists
z*y # R just returns a list of the values, notice they won't appear in the
    # Global environment unless we name it like this . . .
a <- z*y

b <- z+y

# what if the lists are different lengths?
z+x
    # This works because x is not a list
c<- c(5,10)
a+c
    # The shorter list throws an error message, we can tell R to repeat
    # the shorter list, but we'll get to that later

# we can use R to compare lists/values and it will return a 'logical' class
1==2

y!=y

b>=a

# Let's make a dataframe of our lists
df<-data.frame(y,z,a,b)
    # check the type
typeof(df)
str(df)

# Let's try an actual dataset with meaningful values

# R has some built-in datasets for us to play with
data()
data("ToothGrowth")  # Normally, R won't save this unless we name it
                # this is a special case where it's a built in data set

# take a quick look at our data 
head(ToothGrowth) #this just gives us an idea of what our data is, useful for 
            # when you have a lot more data than this

# to target a specific variable within the dataframe use $
ToothGrowth$len

# Rename the columns
colnames(ToothGrowth)<-c("Length", "Type", "Dose")

# let's look at some summary stats
summary(ToothGrowth$Length)
    # the only thing this doesn't give us is sd
sd(ToothGrowth$Length)
    
# split into the different trees
library(dplyr) 
oj_guineas<-ToothGrowth%>%   # this is a pipe, it passes our data to the next line
  filter(Type=="OJ")  # dplyr has 8 actions: mutate, filter, sort, slice, 
                   # arrange, select, rename, summarise

# plot using ggplot
library(ggplot2)
ggplot(data=ToothGrowth, aes(x=Type, y= Length, fill=Type)) +
      # ggplot uses + to add new 'layers' to each plot
  geom_bar(stat="identity")+
      #specify the type of plot with geom_x
  labs(title="Guinea Pig Tooth Growth")+
  theme_classic()

# ggplot is neat because it's flexible and you can find an answer to 
# your questions easily


# Let's play with data that isn't categorical 
library(lubridate)
data("Nile")
Date<-time(Nile)
df_Nile<- data.frame(Nile, Date)

# let's plot it
ggplot(df_Nile)+
  geom_line(aes(Date, Nile))+
  theme_classic()

# Add a line for the average flow
mean(df_Nile$Nile)

ggplot(df_Nile)+
  geom_line(aes(Date, Nile))+
  geom_line(aes(Date, 919.35), linetype="dashed", col="purple")+
  labs(x="Year", y="Nile Flow", title="Nile flow over time")+
  theme_classic()

## Yay! Happy Coding ###






